From 9bdb95c9e34cef640534e5e5a1e2225a80442000 Mon Sep 17 00:00:00 2001
From: HelenHuang <LinHuang@pollex.com.tw>
Date: 星期四, 09 六月 2022 15:48:15 +0800
Subject: [PATCH] TODO#139894 [ footer -最下方說明與保經代合作 ] 文案修改

---
 PAMapp/node_modules/nanoid/async/index.d.ts |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/PAMapp/node_modules/nanoid/async/index.d.ts b/PAMapp/node_modules/nanoid/async/index.d.ts
index 3933d25..9e91965 100644
--- a/PAMapp/node_modules/nanoid/async/index.d.ts
+++ b/PAMapp/node_modules/nanoid/async/index.d.ts
@@ -24,8 +24,8 @@
  * will not be secure.
  *
  * @param alphabet Alphabet used to generate the ID.
  * @param size Size of the ID.
  * @returns A promise with a random string.
  *
  * ```js
  * import { customAlphabet } from 'nanoid/async'
@@ -37,8 +37,8 @@
  */
 export function customAlphabet(
   alphabet: string,
-  size: number
-): () => Promise<string>
+  defaultSize?: number
+): (size?: number) => Promise<string>
 
 /**
  * Generate an array of random bytes collected from hardware noise.
@@ -24,8 +24,8 @@
  *
  * @param alphabet Alphabet used to generate the ID.
- * @param size Size of the ID.
- * @returns A promise with a random string.
+ * @param defaultSize Size of the ID. The default size is 21.
+ * @returns A function that returns a promise with a random string.
  *
  * ```js

--
Gitblit v1.8.0